@@ -481,10 +481,6 @@ class UCR(predict_system.TextSystem):
             postprocess_params.cls_model_location = cls_path
             postprocess_params.cls_config_location = cls_cfg_path
         
-        
-        postprocess_params.rec_char_dict_path = str(
-            Path(__file__).parent / postprocess_params.rec_char_dict_path)
-        print(postprocess_params.rec_char_dict_path)
         super().__init__(postprocess_params)
 
     def predict(self, img, det=True, rec=True):
