@@ -146,9 +146,10 @@ def create_predictor(args, mode, logger):
         logger.info("not find params file path {}".format(config))
         sys.exit(0)
     config = yaml.load(open(config, 'rb'), Loader=yaml.Loader)
+    
     general_params = config['General']
-    general_params.character_dict_path = str(
-        Path(__file__).parent / general_params.character_dict_path)
+    if mode=='rec':
+        general_params["character_dict_path"] = args.rec_char_dict_path
     post_process_class = build_postprocess(config["Postprocess"], general_params)
     
     if hasattr(post_process_class, 'character'):
